<?php
/* 
 * Register a custom post type and create the custom meta box for the options in WP Slick Slider
 */

function wpss_init_post_types(){
    $slidersargs = array(
        labels => array(
            'name' => __( 'Sliders' ),
            'singular_name' => __( 'Slider' ),
            'search_items' =>  __( 'Search Sliders' ),
            'all_items' => __( 'All Sliders' ),
            'parent_item' => __( 'Parent Slider' ),
            'parent_item_colon' => __( 'Parent Slider:' ),
            'edit_item' => __( 'Edit Slider' ),
            'update_item' => __( 'Update Slider' ),
            'add_new_item' => __( 'Add New Slider' ),
            'new_item_name' => __( 'New Slider Name' ),
            'menu_name' => __( 'Sliders' )
        ),
        'hierarchical' => true,
        'show_ui' => true,
        'query_var' => true,
        'rewrite' => false
    );
    register_taxonomy( 'wpss_sliders' , 'wpss_sliders' , $slidersargs);

    $slideargs = array(
            'labels' => array(
                    'name' => 'Slick Slides',
                    'singular_name' => 'Slide',
                    'add_new' => 'New Slide',
                    'add_new_item' => 'Add New Slide',
                    'edit_item' => 'Edit Slide',
                    'new_item' => 'New Slide',
                    'view_item' => 'View Slide',
                    'search_items' => 'Search Slides',
                    'not_found' => 'No Slides Found',
                    'not_found_in_trash' => 'No Slides In The Trash'
            ),
            'description' => 'Slides For The WP Slick Slider',
            'public' => false,
            'show_ui' => true,
            'capability_type' => 'post',
            'hierarchical' => true,
            'taxonomies' => array( 'wpss_sliders' ),
            'supports' => array(
                    'title',
                    'editor',
                    'thumbnail'
            ),
            'rewrite' => false,
            'menu_position' => 5,
            'register_meta_box_cb' => 'wpss_add_slide_meta_box',
            'menu_icon' => WPSS_HTTP_PATH . '/icon.png'
    );
    register_post_type( 'wpss_slides', $slideargs );
}
add_action( 'init' , 'wpss_init_post_types' );

function wpss_add_slide_meta_box(){
	add_meta_box( 'extra_data', 'Slide Information', 'wpss_create_slide_meta_box', 'wpss_slides', 'normal', 'high' );
}

function wpss_create_slide_meta_box(){
	//Collect Some Variables.
	if(isset($_GET['post'])){
		$post_id = $_GET['post'];
                $metadata = get_post_custom( $post_id );
		$type = $metadata['Slide Type'][0];
		$slide_order = $metadata['Slide Order'][0];
	}else{
		$type = '';
		$slide_order = 0;
	}
	//Create a select box of slide types -- //Left, Right, Full Width Image , Full Width Text
	?>
	<p>
		<b>Select The Slide Type</b><br />
		<select name="slide-type">
                    <?php 
                    $opts = array( 'Left Half Image' , 'Right Half Image' , 'Full Width Image' , 'Full Width Text' );
                    $out = '';
                    foreach( $opts as $opt ){
                        $selected = ( $type == $opt ) ? 'selected="selected"' : '' ;
                        $out .= '<option ' . $selected . ' value="' . $opt . '">' . __( $opt ) . '</option>';
                    }
                    echo $out;
                    ?>
		</select>
	</p>
	<p>
	    <b>Slide Number. Use This Option To Reorganize The Order Of The Slides. Use 0 Or Leave Blank To Disable.</b><br />
	    <input size="20" type="text" name="slide-order" value="<?php echo $slide_order; ?>" />
	</p>
<?php
}

function wpss_save_additional_postmeta(){

	$maybe_id = $_POST['post_ID'];

	if(!wp_is_post_revision($maybe_id)){
		$post_id = $maybe_id;
	}else{
		$post_id = wp_is_post_revision($maybe_id);
	}

	//Dont save on autosave:
	if (defined('DOING_AUTOSAVE') && DOING_AUTOSAVE) {
	    return $post_id;
	}

	//Ensure We Are Saving The Custom Post Type:
	if(isset($_POST['post_type']) && $_POST['post_type'] == 'wpss_slides'):

            $slide_type = $_POST['slide-type'];
	    $slide_order = $_POST['slide-order'];
	    $slide_order = ( empty( $slide_order ) || $slide_order == 0 ) ? 0 : $slide_order ;

            //update_post_meta($post_id, $meta_key, $meta_value, $prev_value);
            update_post_meta($post_id, 'Slide Type', $slide_type );
	    update_post_meta($post_id, 'Slide Order', $slide_order );

	endif;
}
add_action('save_post', 'wpss_save_additional_postmeta');

?>