<?php
/* 
 * Admin Options Page And Save Function.
 */


class WPSS_OPTIONS {

    /*
     * Function to run on Init.
     */
    function Init(){

        register_setting( 'wpss_options_group', 'wpss_options' );

        add_settings_section( 'wpss_general_options', 'General Options', array('WPSS_OPTIONS', 'General_Overview'), 'wpss_options_page' );

        /*
         * General Option Fields
         */
        $use_css_data_arr = array(
            'id'          => 'wpss_use_css',
            'description' => 'Uncheck This Box To Disable WP Slick Slider From Using CSS'
        );
        add_settings_field( 'wpss_use_css', 'Disable CSS?', array('WPSS_OPTIONS', 'Checkbox'), 'wpss_options_page', 'wpss_general_options', $use_css_data_arr );

        $use_js_data_arr = array(
            'id' => 'wpss_use_js',
            'description' => 'Uncheck This Box To Disable WP Slick Slider From Using Javascript.<br /> ( Not recommended unless you are going to add it somewhere else, it is necessary to animate the slides! )'
        );
        add_settings_field( 'wpss_use_js', 'Disable Javascript?', array('WPSS_OPTIONS', 'Checkbox'), 'wpss_options_page', 'wpss_general_options', $use_js_data_arr );

        $footer_creds_data_arr = array(
            'id' => 'wpss_footer_credits',
            'description' => 'If you like this plugin, you can enable the addition of a small link in the footer of your website to the author of the plugin'
        );
        add_settings_field( 'wpss_footer_credits', 'Enable Footer Credits?', array('WPSS_OPTIONS', 'Checkbox'), 'wpss_options_page', 'wpss_general_options', $footer_creds_data_arr );


        /*
         * Hook Up The Form Fields For the Add / Edit Slider Forms.
         */
        add_action( 'wpss_sliders_edit_form_fields' , array( 'WPSS_OPTIONS' , 'Edit_Sliders_Fields' ), 10, 2 );
        add_action( 'wpss_sliders_add_form_fields' , array( 'WPSS_OPTIONS' , 'Add_Sliders_Fields' ), 10, 1 );

        add_action( 'created_wpss_sliders' , array( 'WPSS_OPTIONS' , 'Wpss_Save_Slider_Data' ) , 10, 2 );
        add_action( 'edited_wpss_sliders' , array( 'WPSS_OPTIONS' , 'Wpss_Save_Slider_Data' ) , 10, 2 );

    }

    /*
     * Add the admin menus
     */
    function Add_Admin_Menus(){

        add_submenu_page( 'edit.php?post_type=wpss_slides' , 'Slick Slider Options' , 'Options', 'edit_posts', 'wpss-options' , array('WPSS_OPTIONS', 'Options_Page') );

        add_submenu_page( 'edit.php?post_type=wpss_slides&page=wpss-options' , 'Test SubSubSub' , 'Testing', 'edit_posts', 'wpss-options' , array('WPSS_OPTIONS', 'subsubtest') );
    
    }

    /*
     * Default Options For The Sliders
     */
    function Get_Default_Sliders_Options(){
        $opts = array(
            'wpss_timeout' => 2000,
            'wpss_speed' => 500,
            'wpss_pauseonhover' => 'off',
            'wpss_pauseonpagerhover' => 'off',
            'wpss_effects' => array( 'fade' ),
            'wpss_easing' => 'swing',
            'wpss_height' => 250,
            'wpss_fullwidth' => 620,
            'wpss_halfwidth' => 310
            );
        return $opts;
    }

    /*
     * Create the options page
     */
    function Options_Page(){ global $wpss_options; ?>

        <div class="wrap">

            <h2 style="clear:both;"><?php _e( 'WP Slick Slider Options' ); ?></h2>

            <form method="post" action="options.php">

                <?php settings_fields( 'wpss_options_group' ); ?>
                
                <?php do_settings_sections( 'wpss_options_page' ); ?>

                <p class="submit">
                    <input type="submit" class="button-primary" value="<?php _e('Save Changes') ?>" />
                </p>

            </form>

        </div>
        
    <?php }

    /*
     * Create the HTML for the extension of the edit sliders form.
     */
    function Edit_Sliders_Fields( $tag, $taxonomy ){
        
        $data = get_option( 'wpss_' . $tag->slug . '_options' );

        if( ! $data ){ //Something is very wrong...
            $data = WPSS_OPTIONS::Get_Default_Sliders_Options();
        }

        ?>
        <tr class="form-field">
                <th scope="row" valign="top"><label for="wpss_timeout">Timeout</label></th>
                <td>
                    <input name="wpss_timeout" id="wpss_timeout" type="text" value="<?php echo $data['wpss_timeout']; ?>" size="40" /><br />
                    <span class="description"><?php _e('This Controls The Timeout Value Of The Slider'); ?></span>
                </td>
        </tr>

        <tr class="form-field">
                <th scope="row" valign="top"><label for="wpss_speed">Speed</label></th>
                <td>
                    <input name="wpss_speed" id="wpss_speed" type="text" value="<?php echo $data['wpss_speed']; ?>" size="40" /><br />
                    <span class="description"><?php _e('This Controls The Speed Of The Actual Transition'); ?></span>
                </td>
        </tr>

        <tr class="form-field">
                <th scope="row" valign="top"><label for="wpss_pauseonhover">Pause On Hover</label></th>
                <td>
                    <?php $checked = ( $data['wpss_pauseonhover'] == 'on' ) ? 'checked="checked"' : '' ;  ?>
                    <input style="width:15px;" <?php echo $checked; ?> name="wpss_pauseonhover" id="wpss_pauseonhover" type="checkbox" value="on" /><br />
                    <span class="description"><?php _e('Check This Box To Pause The Slideshow Advance When The User Hovers Over It'); ?></span>
                </td>
        </tr>

        <tr class="form-field">
                <th scope="row" valign="top"><label for="wpss_pauseonpagerhover">Pause On Pager Hover</label></th>
                <td>
                    <?php $checked = ( $data['wpss_pauseonpagerhover'] == 'on' ) ? 'checked="checked"' : '' ;  ?>
                    <input style="width:15px;" <?php echo $checked; ?> name="wpss_pauseonpagerhover" id="wpss_pauseonpagerhover" type="checkbox" value="on" /><br />
                    <span class="description"><?php _e('Check This Box To Pause The Slideshow Advance When The User Hovers Over The Pager'); ?></span>
                </td>
        </tr>

        <?php //Effects ?>
        <tr class="form-field">
                <th scope="row" valign="top"><label for="wpss_effects">Effects</label></th>
                <td>
                    <?php
                    $effects = array(
                        'all', 'blindX', 'blindY', 'blindZ', 'cover', 'curtainX', 'curtainY', 'fade', 'fadeZoom',
                        'growX', 'growY', 'scrollUp', 'scrollDown', 'scrollLeft', 'scrollRight', 'scrollHorz', 'scrollVert',
                        'shuffle', 'slideX', 'slideY', 'toss', 'turnUp', 'turnDown', 'turnLeft', 'turnRight', 'uncover',
                        'wipe', 'zoom', 'none'
                    );
                    ?>
                    <select multiple="multiple" style="height:auto;" name="wpss_effects[]" id="wpss_effects">
                        <?php
                        foreach( $effects as $effect ){
                            $selected = ( in_array( $effect , $data['wpss_effects'] ) ) ? 'selected="selected"' : '' ;
                            echo '<option ' . $selected . ' value="' . $effect . '">' . $effect . '</option>';
                        }
                        ?>
                    </select>
                    <br /><span class="description"><?php _e('These are the effects used during the transition, you can select as many as you like.'); ?></span>
                </td>
        </tr>

        <?php //Easing ?>

        <tr class="form-field">
                <th scope="row" valign="top"><label for="wpss_easing">Easing</label></th>
                <td>
                    <?php
                    $easings = array(
                        'linear', 'swing', 'easeInQuad', 'easeOutQuad', 'easeInOutQuad', 'easeInCubic', 'easeOutCubic',
                        'easeInOutCubic', 'easeInQuart', 'easeOutQuart', 'easeInOutQuart', 'easeInQuint', 'easeOutQuint',
                        'easeInOutQuint', 'easeInSine', 'easeOutSine', 'easeInOutSine', 'easeInExpo', 'easeOutExpo', 'easeInOutExpo',
                        'easeInCirc', 'easeOutCirc', 'easeInOutCirc', 'easeInElastic', 'easeOutElastic', 'easeInOutElastic',
                        'easeInBack', 'easeOutBack', 'easeInOutBack', 'easeInBounce', 'easeOutBounce', 'easeInOutBounce', 'none'
                    );
                    ?>
                    <select name="wpss_easing" id="wpss_easing">
                        <?php
                        foreach( $easings as $easing ){
                            $selected = ( $easing == $data['wpss_easing'] ) ? 'selected="selected"' : '' ;
                            echo '<option ' . $selected . ' value="' . $easing . '">' . $easing . '</option>';
                        }
                        ?>
                    </select>
                    <br /><span class="description"><?php _e('This is the easing used in the transition.'); ?></span>
                </td>
        </tr>

        <?php //Height ?>

        <tr class="form-field">
                <th scope="row" valign="top"><label for="wpss_height">Height</label></th>
                <td>
                    <input name="wpss_height" id="wpss_speed" type="text" value="<?php echo $data['wpss_height']; ?>" size="40" /><br />
                    <span class="description"><?php _e('The Height Of The Slider'); ?></span>
                </td>
        </tr>

        <?php //Fullwidth ?>

        <tr class="form-field">
                <th scope="row" valign="top"><label for="wpss_fullwidth">Full Width</label></th>
                <td>
                    <input name="wpss_fullwidth" id="wpss_speed" type="text" value="<?php echo $data['wpss_fullwidth']; ?>" size="40" /><br />
                    <span class="description"><?php _e('The Full Width Image Width'); ?></span>
                </td>
        </tr>

        <?php //Halfwidth ?>

        <tr class="form-field">
                <th scope="row" valign="top"><label for="wpss_halfwidth">Half Width</label></th>
                <td>
                    <input name="wpss_halfwidth" id="wpss_speed" type="text" value="<?php echo $data['wpss_halfwidth']; ?>" size="40" /><br />
                    <span class="description"><?php _e('The Half Width Image Width'); ?></span>
                </td>
        </tr>

        <?php
    }

    /*
     * Create the HTML for the extension of the add slider form.
     */
    function Add_Sliders_Fields( $taxonomy ){
        $data = WPSS_OPTIONS::Get_Default_Sliders_Options();
        ?>

        <div class="form-field">
                <label for="wpss_timeout">Timeout</label>
                <input name="wpss_timeout" id="wpss_timeout" type="text" value="<?php echo $data['wpss_timeout']; ?>" size="40" />
                <p><?php _e('This Controls The Timeout Value Of The Slider'); ?></p>
        </div>

        <div class="form-field">
                <label for="wpss_speed">Speed</label>
                <input name="wpss_speed" id="wpss_speed" type="text" value="<?php echo $data['wpss_speed']; ?>" size="40" /><br />
                <p><?php _e('This Controls The Speed Of The Actual Transition'); ?></p>
        </div>

        <div class="form-field">
                <label for="wpss_pauseonhover">Pause On Hover</label>
                <input style="width:15px;" name="wpss_pauseonhover" id="wpss_pauseonhover" type="checkbox" value="on" />
                <p><?php _e('Check This Box To Pause The Slideshow Advance When The User Hovers Over It'); ?></p>
        </div>

        <div class="form-field">
                <label for="wpss_pauseonpagerhover">Pause On Pager Hover</label>
                <input style="width:15px;" name="wpss_pauseonpagerhover" id="wpss_pauseonpagerhover" type="checkbox" value="on" />
                <p><?php _e('Check This Box To Pause The Slideshow Advance When The User Hovers Over The Pager'); ?></p>
        </div>

        <?php //Effects ?>
        <div class="form-field">
                <label for="wpss_effects">Effects</label>
                <?php
                    $effects = array(
                        'all', 'blindX', 'blindY', 'blindZ', 'cover', 'curtainX', 'curtainY', 'fade', 'fadeZoom',
                        'growX', 'growY', 'scrollUp', 'scrollDown', 'scrollLeft', 'scrollRight', 'scrollHorz', 'scrollVert',
                        'shuffle', 'slideX', 'slideY', 'toss', 'turnUp', 'turnDown', 'turnLeft', 'turnRight', 'uncover',
                        'wipe', 'zoom', 'none'
                    );
                ?>
                <select multiple="multiple" style="height:auto;" name="wpss_effects[]" id="wpss_effects">
                    <?php
                    foreach( $effects as $effect ){
                        $selected = ( in_array( $effect , $data['wpss_effects'] ) ) ? 'selected="selected"' : '' ;
                        echo '<option ' . $selected . ' value="' . $effect . '">' . $effect . '</option>';
                    }
                    ?>
                </select>
                <p><?php _e('These are the effects used during the transition, you can select as many as you like.'); ?></p>
        </div>

        <?php //Easing ?>

        <div class="form-field">
                <label for="wpss_easing">Easing</label>
                <?php
                    $easings = array(
                        'linear', 'swing', 'easeInQuad', 'easeOutQuad', 'easeInOutQuad', 'easeInCubic', 'easeOutCubic',
                        'easeInOutCubic', 'easeInQuart', 'easeOutQuart', 'easeInOutQuart', 'easeInQuint', 'easeOutQuint',
                        'easeInOutQuint', 'easeInSine', 'easeOutSine', 'easeInOutSine', 'easeInExpo', 'easeOutExpo', 'easeInOutExpo',
                        'easeInCirc', 'easeOutCirc', 'easeInOutCirc', 'easeInElastic', 'easeOutElastic', 'easeInOutElastic',
                        'easeInBack', 'easeOutBack', 'easeInOutBack', 'easeInBounce', 'easeOutBounce', 'easeInOutBounce', 'none'
                    );
                ?>
                <select name="wpss_easing" id="wpss_easing">
                    <?php
                    foreach( $easings as $easing ){
                        $selected = ( $easing == $data['wpss_easing'] ) ? 'selected="selected"' : '' ;
                        echo '<option ' . $selected . ' value="' . $easing . '">' . $easing . '</option>';
                    }
                    ?>
                </select>
                <p><?php _e('This is the easing used in the transition.'); ?></p>
        </div>

        <?php //Height ?>

        <div class="form-field">
                <label for="wpss_height">Height</label>
                <input name="wpss_height" id="wpss_speed" type="text" value="<?php echo $data['wpss_height']; ?>" size="40" />
                <p><?php _e('The Height Of The Slider'); ?></p>
        </div>

        <?php //Fullwidth ?>

        <div class="form-field">
                <label for="wpss_fullwidth">Full Width</label>
                <input name="wpss_fullwidth" id="wpss_speed" type="text" value="<?php echo $data['wpss_fullwidth']; ?>" size="40" />
                <p><?php _e('The Full Width Image Width'); ?></p>
        </div>

        <?php //Halfwidth ?>

        <div class="form-field">
                <label for="wpss_halfwidth">Half Width</label>
                <input name="wpss_halfwidth" id="wpss_speed" type="text" value="<?php echo $data['wpss_halfwidth']; ?>" size="40" />
                <p><?php _e('The Half Width Image Width'); ?></p>
        </div>

        <?php
    }

    /*
     * Save the data
     */
    function Wpss_Save_Slider_Data( $term_id, $tt_id ){
        $fields = array(
            'wpss_timeout',
            'wpss_speed',
            'wpss_pauseonhover',
            'wpss_pauseonpagerhover',
            'wpss_effects',
            'wpss_easing',
            'wpss_height',
            'wpss_fullwidth',
            'wpss_halfwidth'
        );

        //Get the original data
        $data = WPSS_OPTIONS::Get_Default_Sliders_Options();

        $slug = ( empty( $_POST['slug'] ) ) ? strtolower( str_replace( ' ' , '-' , $_POST['name'] ) ) :  $_POST['slug'] ;

        foreach( $fields as $field ){

            if( isset( $_POST[$field] ) ){
                $data[$field] = $_POST[$field];
            }

        }
        update_option( 'wpss_' . $slug . '_options' , $data );
        
    }

    /*
     * Output General Info
     */
    function General_Overview(){
        _e( '<p>These are the general options for controlling the WP Slick Slider. You can control the effects of each slider individually, This is done in the slider edit page.</p>' );
    }

    /**
     *
     * Output A Checkbox, $data should be in the following format:
     * $data = array(
     *  'id' => 'id_of_the_element',
     *  'description' => 'Option Description.'
     * )
     */
    function Checkbox( $data ){
        global $wpss_options;

        $checked = ( isset( $wpss_options[ $data['id'] ] ) ) ? 'checked="checked"' : '' ;

        echo '<input ' . $checked . ' id="' . $data['id'] . '" name="wpss_options[' . $data['id'] . ']" type="checkbox" /> <span class="description">' . $data['description'] . '</span>';
        
    }

    /*
     * Output a Text input field
     */
    function TextInput( $data ){
        global $wpss_options;

        echo '<input id="' . $data['id'] . '" name="wpss_options[' . $data['id'] . ']" size="40" type="text" value="' . $wpss_options[ $data['id'] ] . '" /> <span class="description">' . $data['description'] . '</span>';

    }

    /*
     * Output A Select Field
     */
    function Select( $data ){
        global $wpss_options;

        echo '<select name="wpss_options[' . $data['id'] . ']">';
        foreach( $data['options'] as $option ){

            $selected = ( $option == $wpss_options[ $data['id'] ] ) ? 'selected="selected"' : '' ;
            echo '<option ' . $selected . ' value="' . $option . '">' . $option . '</option>';

        }
        echo '</select> <span class="description">' . $data['description'] . '</span>';

    }

    /*
     * Output A Multiselect Field
     */
    function MultiSelect( $data ){
        global $wpss_options;

        echo '<select style="height:auto;" name="wpss_options[' . $data['id'] . '][]" multiple="multiple">';
        foreach( $data['options'] as $option ){

            $selected = ( in_array( $option, $wpss_options[ $data['id'] ] ) ) ? 'selected="selected"' : '' ;
            echo '<option ' . $selected . ' value="' . $option . '">' . $option . '</option>';
            
        }
        echo '</select> <span class="description">' . $data['description'] . '</span>';

    }

    
}
?>